@@ -53,6 +53,9 @@ def plot(
         [arg for arg in args if arg != None], axis_data=None
     )
 
+    if unit is None:
+        unit = self.components[list(self.components.keys())[0]].unit
+
     wid = DDataPlotter(
         data=self,
         axes_request_list=axes_request_list,
@@ -61,7 +64,6 @@ def plot(
         z_min=z_min,
         z_max=z_max,
         is_auto_refresh=is_auto_refresh,
-        plot_arg_dict=None,
         frozen_type=frozen_type,
     )
 
